@@ -68,11 +68,12 @@ validMizerParams <- function(object) {
                length(dim(object@search_vol)),
                length(dim(object@metab)),
                length(dim(object@mu_b)),
+               length(dim(object@ext_encounter)),
                length(dim(object@interaction)),
                length(dim(object@maturity)),
                length(dim(object@ft_mask)),
                length(dim(object@catchability))) == 2)) {
-        msg <- "initial_n, psi, intake_max, search_vol, metab, mu_b, interaction, maturity, ft_mask and catchability must all be two dimensions"
+        msg <- "initial_n, psi, intake_max, search_vol, metab, mu_b, ext_encounter, interaction, maturity, ft_mask and catchability must all be two dimensions"
         errors <- c(errors, msg)
     }
     # 3D arrays
@@ -89,13 +90,14 @@ validMizerParams <- function(object) {
         dim(object@search_vol)[1],
         dim(object@metab)[1],
         dim(object@mu_b)[1],
+        dim(object@ext_encounter)[1],
         dim(object@selectivity)[2],
         dim(object@catchability)[2],
         dim(object@interaction)[1],
         dim(object@interaction)[2],
         dim(object@ft_mask)[1]) == 
         dim(object@species_params)[1])) {
-        msg <- "The number of species in the model must be consistent across the species_params, psi, intake_max, search_vol, mu_b, interaction (dim 1), selectivity, catchability and interaction (dim 2) slots"
+        msg <- "The number of species in the model must be consistent across the species_params, psi, intake_max, search_vol, mu_b, ext_encounter, interaction (dim 1), selectivity, catchability and interaction (dim 2) slots"
         errors <- c(errors, msg)
     }
     # Check number of size groups
@@ -104,12 +106,13 @@ validMizerParams <- function(object) {
         dim(object@maturity)[2],
         dim(object@psi)[2],
         dim(object@mu_b)[2],
+        dim(object@ext_encounter)[2],
         dim(object@intake_max)[2],
         dim(object@search_vol)[2],
         dim(object@metab)[2],
         dim(object@selectivity)[3]) ==
         no_w)) {
-        msg <- "The number of size bins in the model must be consistent across the w, initial_n, maturity, psi, mu_b, intake_max, search_vol, and selectivity (dim 3) slots"
+        msg <- "The number of size bins in the model must be consistent across the w, initial_n, maturity, psi, mu_b, ext_encounter, intake_max, search_vol, and selectivity (dim 3) slots"
         errors <- c(errors, msg)
     }
     # Check number of gears
@@ -127,9 +130,10 @@ validMizerParams <- function(object) {
         names(dimnames(object@search_vol))[1],
         names(dimnames(object@metab))[1],
         names(dimnames(object@mu_b))[1],
+        names(dimnames(object@ext_encounter))[1],
         names(dimnames(object@selectivity))[2],
         names(dimnames(object@catchability))[2]) == "sp")) {
-        msg <- "Name of first dimension of initial_n, maturity, psi, intake_max, search_vol, metab, mu_b, and the second dimension of selectivity and catchability must be 'sp'"
+        msg <- "Name of first dimension of initial_n, maturity, psi, intake_max, search_vol, metab, mu_b, ext_encounter and the second dimension of selectivity and catchability must be 'sp'"
         errors <- c(errors, msg)
     }
     #interaction dimension names
@@ -165,12 +169,13 @@ validMizerParams <- function(object) {
         dimnames(object@search_vol)[[1]],
         dimnames(object@metab)[[1]],
         dimnames(object@mu_b)[[1]],
+        dimnames(object@ext_encounter)[[1]],
         dimnames(object@selectivity)[[2]],
         dimnames(object@catchability)[[2]],
         dimnames(object@interaction)[[1]],
         dimnames(object@interaction)[[2]]) ==
         object@species_params$species)) {
-        msg <- "The species names of species_params, psi, intake_max, search_vol, metab, mu_b, selectivity, catchability and interaction must all be the same"
+        msg <- "The species names of species_params, psi, intake_max, search_vol, metab, mu_b, ext_encounter, selectivity, catchability and interaction must all be the same"
         errors <- c(errors, msg)
     }
     # Check dimnames of w
@@ -302,6 +307,8 @@ validMizerParams <- function(object) {
 #'   for each species at size. Changed with [setMetabolicRate()].
 #' @slot mu_b An array (species x size) that holds the external mortality rate
 #'   \eqn{\mu_{ext.i}(w)}. Changed with [setExtMort()].
+#' @slot ext_encounter An array (species x size) that holds the external encounter rate
+#'   \eqn{E_{ext.i}(w)}. Changed with [setExtEncounter()].
 #' @slot pred_kernel An array (species x predator size x prey size) that holds
 #'   the predation coefficient of each predator at size on each prey size. If
 #'   this is NA then the following two slots will be used. Changed with 
@@ -339,7 +346,9 @@ validMizerParams <- function(object) {
 #' @slot sc `r lifecycle::badge("experimental")`
 #'   The community abundance of the scaling community
 #' @slot species_params A data.frame to hold the species specific parameters.
-#'   See [newMultispeciesParams()] for details.
+#'   See [species_params()] for details.
+#' @slot given_species_params A data.frame to hold the species parameters that
+#'   were given explicitly rather than obtained by default calculations.
 #' @slot gear_params Data frame with parameters for gear selectivity. See 
 #'   [setFishing()] for details.
 #' @slot interaction The species specific interaction matrix, \eqn{\theta_{ij}}.
@@ -397,6 +406,7 @@ setClass(
         ft_pred_kernel_e = "array",
         ft_pred_kernel_p = "array",
         mu_b = "array",
+        ext_encounter = "array",
         rr_pp = "numeric",
         cc_pp = "numeric",
         resource_dynamics = "character",
@@ -410,6 +420,7 @@ setClass(
         initial_n_pp = "numeric",
         initial_n_other = "list",
         species_params = "data.frame",
+        given_species_params = "data.frame",
         interaction = "array",
         gear_params = "data.frame",
         selectivity = "array",
@@ -485,12 +496,14 @@ emptyParams <- function(species_params,
                 is.data.frame(gear_params),
                 no_w > 10)
     
+    given_species_params <- validSpeciesParams(species_params)
+    
     ## Set defaults ----
     if (is.na(min_w_pp)) min_w_pp <- 1e-12
     species_params <- set_species_param_default(species_params, "w_min", min_w)
     min_w <- min(species_params$w_min)
     
-    species_params <- validSpeciesParams(species_params)
+    species_params <- completeSpeciesParams(species_params)
     gear_params <- validGearParams(gear_params, species_params)
     
     if (is.na(max_w)) {
@@ -670,6 +683,7 @@ emptyParams <- function(species_params,
         search_vol = mat1,
         metab = mat1,
         mu_b = mat1,
+        ext_encounter = mat1,
         ft_pred_kernel_e = ft_pred_kernel,
         ft_pred_kernel_p = ft_pred_kernel,
         pred_kernel = array(),
@@ -682,6 +696,7 @@ emptyParams <- function(species_params,
         sc = w,
         initial_n_pp = vec1,
         species_params = species_params,
+        given_species_params = given_species_params,
         interaction = interaction,
         other_dynamics = list(),
         other_encounter = list(),
