@@ -13,22 +13,22 @@ test_that("newTraitParams produces errors and messages", {
                    "The reproduction level must be smaller than 1 and non-negative.")
     expect_error(newTraitParams(min_w = -1),
                  "The smallest egg size min_w must be greater than zero.")
-    expect_error(newTraitParams(min_w_inf = 10^4),
-                 "The asymptotic size of the smallest species min_w_inf must be smaller than")
+    expect_error(newTraitParams(min_w_max = 10^4),
+                 "The maximum size of the smallest species min_w_max must be smaller than")
 })
 # * Multiple gears work correctly in trait-based model ----
 test_that("Multiple gears work correctly in trait-based model", {
     # Check multiple gears are working properly
-    min_w_inf <- 10
-    max_w_inf <- 1e5
+    min_w_max <- 10
+    max_w_max <- 1e5
     no_sp <- 10
-    w_inf <- 10^seq(from = log10(min_w_inf), 
-                    to = log10(max_w_inf), 
+    w_max <- 10^seq(from = log10(min_w_max), 
+                    to = log10(max_w_max), 
                     length = no_sp)
-    knife_edges <- w_inf * 0.05
+    knife_edges <- w_max * 0.05
     params <- newTraitParams(no_sp = no_sp, 
-                             min_w_inf = min_w_inf, 
-                             max_w_inf = max_w_inf, 
+                             min_w_max = min_w_max, 
+                             max_w_max = max_w_max, 
                              knife_edge_size = knife_edges)
     expect_identical(params@gear_params$knife_edge_size, 
                      knife_edges)
@@ -41,8 +41,8 @@ test_that("Multiple gears work correctly in trait-based model", {
     }
     # Only the 4th gear fires
     params <- newTraitParams(no_sp = no_sp, 
-                             min_w_inf = min_w_inf, 
-                             max_w_inf = max_w_inf, 
+                             min_w_max = min_w_max, 
+                             max_w_max = max_w_max, 
                              knife_edge_size = knife_edges, 
                              gear_names = 1:no_sp)
     effort <- c(0,0,0,1,0,0,0,0,0,0)
